@@ -98,7 +98,7 @@ void Connection_setAvailable(T C, int isAvailable);
  * @param C A Connection object
  * @return true If this Connection is available otherwise false
  */
-int Connection_isAvailable(T C);
+bool Connection_isAvailable(T C);
 
 
 /**
@@ -118,7 +118,7 @@ time_t Connection_getLastAccessedTime(T C);
  * @param C A Connection object
  * @return true if this Connection is in a transaction otherwise false
  */
-int Connection_isInTransaction(T C);
+bool Connection_isInTransaction(T C);
 
 
 //>> End Protected methods
@@ -128,13 +128,13 @@ int Connection_isInTransaction(T C);
 
 /**
  * Sets the number of milliseconds the Connection should wait for a
- * SQL statement to finish if the database is busy. If the limit is
- * exceeded, then the <code>execute</code> methods will return
- * immediately with an error. The default timeout is <code>3
- * seconds</code>.
+ * SQL (select) statement to finish if the database is busy. If the limit is
+ * exceeded, the statement will return immediately with an error.
+ * The timeout is set per connection/session. Not all database systems
+ * supports query timeout. The default is no query timeout.
  * @param C A Connection object
  * @param ms The query timeout limit in milliseconds; zero means
- * there is no limit
+ * there is no timeout limit. Zero is the default value.
  */
 void Connection_setQueryTimeout(T C, int ms);
 
@@ -144,7 +144,7 @@ void Connection_setQueryTimeout(T C, int ms);
  * SQL statement object to execute.
  * @param C A Connection object
  * @return The query timeout limit in milliseconds; zero means there
- * is no limit
+ * is no timeout limit
  */
 int Connection_getQueryTimeout(T C);
 
@@ -169,6 +169,32 @@ void Connection_setMaxRows(T C, int max);
 int Connection_getMaxRows(T C);
 
 
+/**
+ * Specify the number of rows that should be fetched from the database
+ * when more rows are needed for ResultSet objects generated by this 
+ * Connection. The default value is 100, meaning that a ResultSet will
+ * prefetch rows in batches of 100 rows to reduce the network roundtrip
+ * to the database. This value can also be set via the URL parameter
+ * <code>fetch-size</code> to apply to all connections. This method and
+ * the concept of pre-fetching rows are only applicable to MySQL and Oracle.
+ * @param C A Connection object
+ * @param rows The number of rows to fetch (1..INT.MAX)
+ * @exception AssertException If <code>rows</code> is less than 1
+ */
+void Connection_setFetchSize(T C, int rows);
+
+
+/**
+ * Get the number of rows that should be fetched from the database
+ * when more rows are needed for ResultSet objects generated by this
+ * Connection. This method and the concept of pre-fetching rows are only
+ * applicable to MySQL and Oracle.
+ * @param C A Connection object
+ * @return The number of rows to fetch
+ */
+int Connection_getFetchSize(T C);
+
+
 /**
  * Returns this Connection URL
  * @param C A Connection object
@@ -180,13 +206,13 @@ URL_T Connection_getURL(T C);
 //@}
 
 /**
- * Ping the database server and returns true if this Connection is 
+ * Ping the database server and return true if this Connection is 
  * alive, otherwise false in which case the Connection should be closed. 
  * @param C A Connection object
  * @return true if Connection is connected to a database server 
  * otherwise false
  */
-int Connection_ping(T C);
+bool Connection_ping(T C);
 
 
 /**
@@ -342,7 +368,7 @@ const char *Connection_getLastError(T C);
  * @param url A database url string
  * @return true if supported otherwise false
  */
-int Connection_isSupported(const char *url);
+bool Connection_isSupported(const char *url);
 
 // @}
 
