@@ -27,12 +27,8 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <mysql.h>
 
-#include "ResultSet.h"
-#include "MysqlResultSet.h"
-#include "PreparedStatementDelegate.h"
-#include "MysqlPreparedStatement.h"
+#include "MysqlAdapter.h"
 
 
 /**
@@ -42,64 +38,47 @@
  */
 
 
-/* ----------------------------------------------------------- Definitions */
+/* ------------------------------------------------------------- Definitions */
 
 
 #define MYSQL_OK 0
-
-const struct Pop_T mysqlpops = {
-        .name           = "mysql",
-        .free           = MysqlPreparedStatement_free,
-        .setString      = MysqlPreparedStatement_setString,
-        .setInt         = MysqlPreparedStatement_setInt,
-        .setLLong       = MysqlPreparedStatement_setLLong,
-        .setDouble      = MysqlPreparedStatement_setDouble,
-        .setTimestamp   = MysqlPreparedStatement_setTimestamp,
-        .setBlob        = MysqlPreparedStatement_setBlob,
-        .execute        = MysqlPreparedStatement_execute,
-        .executeQuery   = MysqlPreparedStatement_executeQuery,
-        .rowsChanged    = MysqlPreparedStatement_rowsChanged
-};
-
 typedef struct param_t {
         union {
+                double real;
                 int integer;
                 long long llong;
-                double real;
                 MYSQL_TIME timestamp;
         } type;
         long length;
 } *param_t;
-
 #define T PreparedStatementDelegate_T
 struct T {
-        int maxRows;
         int lastError;
         param_t params;
         MYSQL_STMT *stmt;
         MYSQL_BIND *bind;
         int parameterCount;
+        Connection_T delegator;
 };
-
+#if MYSQL_VERSION_ID < 80000 || MARIADB_VERSION_ID
 static my_bool yes = true;
-
+#else
+static bool yes = true;
+#endif
 extern const struct Rop_T mysqlrops;
 
 
-/* ----------------------------------------------------- Protected methods */
+/* ------------------------------------------------------------- Constructor */
 
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility push(hidden)
-#endif
-
-T MysqlPreparedStatement_new(void *stmt, int maxRows, int parameterCount) {
+T MysqlPreparedStatement_new(Connection_T delegator, MYSQL_STMT *stmt) {
         T P;
+        assert(delegator);
         assert(stmt);
         NEW(P);
+        P->delegator = delegator;
         P->stmt = stmt;
-        P->maxRows = maxRows;
-        P->parameterCount = parameterCount;
+        P->parameterCount = (int)mysql_stmt_param_count(stmt);
         if (P->parameterCount > 0) {
                 P->params = CALLOC(P->parameterCount, sizeof(struct param_t));
                 P->bind = CALLOC(P->parameterCount, sizeof(MYSQL_BIND));
@@ -109,7 +88,10 @@ T MysqlPreparedStatement_new(void *stmt, int maxRows, int parameterCount) {
 }
 
 
-void MysqlPreparedStatement_free(T *P) {
+/* -------------------------------------------------------- Delegate Methods */
+
+
+static void _free(T *P) {
 	assert(P && *P);
         FREE((*P)->bind);
         mysql_stmt_free_result((*P)->stmt);
@@ -124,7 +106,7 @@ void MysqlPreparedStatement_free(T *P) {
 }
 
 
-void MysqlPreparedStatement_setString(T P, int parameterIndex, const char *x) {
+static void _setString(T P, int parameterIndex, const char *x) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         P->bind[i].buffer_type = MYSQL_TYPE_STRING;
@@ -140,7 +122,7 @@ void MysqlPreparedStatement_setString(T P, int parameterIndex, const char *x) {
 }
 
 
-void MysqlPreparedStatement_setInt(T P, int parameterIndex, int x) {
+static void _setInt(T P, int parameterIndex, int x) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         P->params[i].type.integer = x;
@@ -150,7 +132,7 @@ void MysqlPreparedStatement_setInt(T P, int parameterIndex, int x) {
 }
 
 
-void MysqlPreparedStatement_setLLong(T P, int parameterIndex, long long x) {
+static void _setLLong(T P, int parameterIndex, long long x) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         P->params[i].type.llong = x;
@@ -160,7 +142,7 @@ void MysqlPreparedStatement_setLLong(T P, int parameterIndex, long long x) {
 }
 
 
-void MysqlPreparedStatement_setDouble(T P, int parameterIndex, double x) {
+static void _setDouble(T P, int parameterIndex, double x) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         P->params[i].type.real = x;
@@ -170,7 +152,7 @@ void MysqlPreparedStatement_setDouble(T P, int parameterIndex, double x) {
 }
 
 
-void MysqlPreparedStatement_setTimestamp(T P, int parameterIndex, time_t x) {
+static void _setTimestamp(T P, int parameterIndex, time_t x) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         struct tm ts = {.tm_isdst = -1};
@@ -187,7 +169,7 @@ void MysqlPreparedStatement_setTimestamp(T P, int parameterIndex, time_t x) {
 }
 
 
-void MysqlPreparedStatement_setBlob(T P, int parameterIndex, const void *x, int size) {
+static void _setBlob(T P, int parameterIndex, const void *x, int size) {
         assert(P);
         int i = checkAndSetParameterIndex(parameterIndex, P->parameterCount);
         P->bind[i].buffer_type = MYSQL_TYPE_BLOB;
@@ -203,11 +185,12 @@ void MysqlPreparedStatement_setBlob(T P, int parameterIndex, const void *x, int
 }
 
 
-void MysqlPreparedStatement_execute(T P) {
+static void _execute(T P) {
         assert(P);
-        if (P->parameterCount > 0)
+        if (P->parameterCount > 0) {
                 if ((P->lastError = mysql_stmt_bind_param(P->stmt, P->bind)))
                         THROW(SQLException, "%s", mysql_stmt_error(P->stmt));
+        }
 #if MYSQL_VERSION_ID >= 50002
         unsigned long cursor = CURSOR_TYPE_NO_CURSOR;
         mysql_stmt_attr_set(P->stmt, STMT_ATTR_CURSOR_TYPE, &cursor);
@@ -221,11 +204,12 @@ void MysqlPreparedStatement_execute(T P) {
 }
 
 
-ResultSet_T MysqlPreparedStatement_executeQuery(T P) {
+static ResultSet_T _executeQuery(T P) {
         assert(P);
-        if (P->parameterCount > 0)
+        if (P->parameterCount > 0) {
                 if ((P->lastError = mysql_stmt_bind_param(P->stmt, P->bind)))
                         THROW(SQLException, "%s", mysql_stmt_error(P->stmt));
+        }
 #if MYSQL_VERSION_ID >= 50002
         unsigned long cursor = CURSOR_TYPE_READ_ONLY;
         mysql_stmt_attr_set(P->stmt, STMT_ATTR_CURSOR_TYPE, &cursor);
@@ -233,18 +217,40 @@ ResultSet_T MysqlPreparedStatement_executeQuery(T P) {
         if ((P->lastError = mysql_stmt_execute(P->stmt)))
                 THROW(SQLException, "%s", mysql_stmt_error(P->stmt));
         if (P->lastError == MYSQL_OK)
-                return ResultSet_new(MysqlResultSet_new(P->stmt, P->maxRows, true), (Rop_T)&mysqlrops);
+                return ResultSet_new(MysqlResultSet_new(P->delegator, P->stmt, true), (Rop_T)&mysqlrops);
         THROW(SQLException, "%s", mysql_stmt_error(P->stmt));
         return NULL;
 }
 
 
-long long MysqlPreparedStatement_rowsChanged(T P) {
+static long long _rowsChanged(T P) {
         assert(P);
         return (long long)mysql_stmt_affected_rows(P->stmt);
 }
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility pop
-#endif
+
+static int _parameterCount(T P) {
+        assert(P);
+        return P->parameterCount;
+}
+
+
+/* ------------------------------------------------------------------------- */
+
+
+const struct Pop_T mysqlpops = {
+        .name           = "mysql",
+        .free           = _free,
+        .setString      = _setString,
+        .setInt         = _setInt,
+        .setLLong       = _setLLong,
+        .setDouble      = _setDouble,
+        .setTimestamp   = _setTimestamp,
+        .setBlob        = _setBlob,
+        .execute        = _execute,
+        .executeQuery   = _executeQuery,
+        .rowsChanged    = _rowsChanged,
+        .parameterCount = _parameterCount
+
+};
 
